@@ -48,7 +48,7 @@ class Scoreboard:
         self.critera = Handler._translate(critera)
         if display_name is None:
             display_name = Handler._translate(name, convert=True)
-        self.display_name = Handler._translate(display_name, convert=True)
+        self.display_name = display_name
 
         if create:
             if self.display_name is None:
